[−][src]Enum moore_svlog_syntax::ast::AllNode
An exhaustive list of all nodes.
Variants
Root(&'a Root<'a>)SourceFile(&'a SourceFile<'a>)Item(&'a Item<'a>)Module(&'a Module<'a>)Interface(&'a Interface<'a>)Package(&'a Package<'a>)Type(&'a Type<'a>)TypeKind(&'a TypeKind<'a>)Enum(&'a Enum<'a>)EnumName(&'a EnumName<'a>)Struct(&'a Struct<'a>)StructMember(&'a StructMember<'a>)Port(&'a Port<'a>)PortDecl(&'a PortDecl<'a>)Procedure(&'a Procedure<'a>)Stmt(&'a Stmt<'a>)VarDecl(&'a VarDecl<'a>)VarDeclName(&'a VarDeclName<'a>)GenvarDecl(&'a GenvarDecl<'a>)ForeachIndex(&'a ForeachIndex<'a>)Expr(&'a Expr<'a>)ClassDecl(&'a ClassDecl<'a>)Typedef(&'a Typedef<'a>)SubroutineDecl(&'a SubroutineDecl<'a>)SubroutinePrototype(&'a SubroutinePrototype<'a>)SubroutinePort(&'a SubroutinePort<'a>)NetDecl(&'a NetDecl<'a>)PatternField(&'a PatternField<'a>)ImportDecl(&'a ImportDecl<'a>)ImportItem(&'a ImportItem<'a>)Inst(&'a Inst<'a>)InstName(&'a InstName<'a>)Modport(&'a Modport<'a>)ModportName(&'a ModportName<'a>)ModportPort(&'a ModportPort<'a>)ModportSimplePort(&'a ModportSimplePort<'a>)ParamDecl(&'a ParamDecl<'a>)ParamTypeDecl(&'a ParamTypeDecl<'a>)ParamValueDecl(&'a ParamValueDecl<'a>)ContAssign(&'a ContAssign<'a>)GenerateFor(&'a GenerateFor<'a>)GenerateIf(&'a GenerateIf<'a>)GenerateCase(&'a GenerateCase<'a>)GenerateBlock(&'a GenerateBlock<'a>)PortConn(&'a PortConn<'a>)DpiDecl(&'a DpiDecl<'a>)DataType(&'a DataType<'a>)ImplicitDataType(&'a ImplicitDataType<'a>)VarDim(&'a VarDim<'a>)PackedDim(&'a PackedDim<'a>)UnpackedDim(&'a UnpackedDim<'a>)PathSegment(&'a PathSegment<'a>)Implementations
impl<'a> AllNode<'a>[src]
pub fn get_root(self) -> Option<&'a Root<'a>>[src]
Get the underlying Root, or None if the node is not a Root.
pub fn get_source_file(self) -> Option<&'a SourceFile<'a>>[src]
Get the underlying SourceFile, or None if the node is not a SourceFile.
pub fn get_item(self) -> Option<&'a Item<'a>>[src]
Get the underlying Item, or None if the node is not a Item.
pub fn get_module(self) -> Option<&'a Module<'a>>[src]
Get the underlying Module, or None if the node is not a Module.
pub fn get_interface(self) -> Option<&'a Interface<'a>>[src]
Get the underlying Interface, or None if the node is not a Interface.
pub fn get_package(self) -> Option<&'a Package<'a>>[src]
Get the underlying Package, or None if the node is not a Package.
pub fn get_type(self) -> Option<&'a Type<'a>>[src]
Get the underlying Type, or None if the node is not a Type.
pub fn get_type_kind(self) -> Option<&'a TypeKind<'a>>[src]
Get the underlying TypeKind, or None if the node is not a TypeKind.
pub fn get_enum(self) -> Option<&'a Enum<'a>>[src]
Get the underlying Enum, or None if the node is not a Enum.
pub fn get_enum_name(self) -> Option<&'a EnumName<'a>>[src]
Get the underlying EnumName, or None if the node is not a EnumName.
pub fn get_struct(self) -> Option<&'a Struct<'a>>[src]
Get the underlying Struct, or None if the node is not a Struct.
pub fn get_struct_member(self) -> Option<&'a StructMember<'a>>[src]
Get the underlying StructMember, or None if the node is not a StructMember.
pub fn get_port(self) -> Option<&'a Port<'a>>[src]
Get the underlying Port, or None if the node is not a Port.
pub fn get_port_decl(self) -> Option<&'a PortDecl<'a>>[src]
Get the underlying PortDecl, or None if the node is not a PortDecl.
pub fn get_procedure(self) -> Option<&'a Procedure<'a>>[src]
Get the underlying Procedure, or None if the node is not a Procedure.
pub fn get_stmt(self) -> Option<&'a Stmt<'a>>[src]
Get the underlying Stmt, or None if the node is not a Stmt.
pub fn get_var_decl(self) -> Option<&'a VarDecl<'a>>[src]
Get the underlying VarDecl, or None if the node is not a VarDecl.
pub fn get_var_decl_name(self) -> Option<&'a VarDeclName<'a>>[src]
Get the underlying VarDeclName, or None if the node is not a VarDeclName.
pub fn get_genvar_decl(self) -> Option<&'a GenvarDecl<'a>>[src]
Get the underlying GenvarDecl, or None if the node is not a GenvarDecl.
pub fn get_foreach_index(self) -> Option<&'a ForeachIndex<'a>>[src]
Get the underlying ForeachIndex, or None if the node is not a ForeachIndex.
pub fn get_expr(self) -> Option<&'a Expr<'a>>[src]
Get the underlying Expr, or None if the node is not a Expr.
pub fn get_class_decl(self) -> Option<&'a ClassDecl<'a>>[src]
Get the underlying ClassDecl, or None if the node is not a ClassDecl.
pub fn get_typedef(self) -> Option<&'a Typedef<'a>>[src]
Get the underlying Typedef, or None if the node is not a Typedef.
pub fn get_subroutine_decl(self) -> Option<&'a SubroutineDecl<'a>>[src]
Get the underlying SubroutineDecl, or None if the node is not a SubroutineDecl.
pub fn get_subroutine_prototype(self) -> Option<&'a SubroutinePrototype<'a>>[src]
Get the underlying SubroutinePrototype, or None if the node is not a SubroutinePrototype.
pub fn get_subroutine_port(self) -> Option<&'a SubroutinePort<'a>>[src]
Get the underlying SubroutinePort, or None if the node is not a SubroutinePort.
pub fn get_net_decl(self) -> Option<&'a NetDecl<'a>>[src]
Get the underlying NetDecl, or None if the node is not a NetDecl.
pub fn get_pattern_field(self) -> Option<&'a PatternField<'a>>[src]
Get the underlying PatternField, or None if the node is not a PatternField.
pub fn get_import_decl(self) -> Option<&'a ImportDecl<'a>>[src]
Get the underlying ImportDecl, or None if the node is not a ImportDecl.
pub fn get_import_item(self) -> Option<&'a ImportItem<'a>>[src]
Get the underlying ImportItem, or None if the node is not a ImportItem.
pub fn get_inst(self) -> Option<&'a Inst<'a>>[src]
Get the underlying Inst, or None if the node is not a Inst.
pub fn get_inst_name(self) -> Option<&'a InstName<'a>>[src]
Get the underlying InstName, or None if the node is not a InstName.
pub fn get_modport(self) -> Option<&'a Modport<'a>>[src]
Get the underlying Modport, or None if the node is not a Modport.
pub fn get_modport_name(self) -> Option<&'a ModportName<'a>>[src]
Get the underlying ModportName, or None if the node is not a ModportName.
pub fn get_modport_port(self) -> Option<&'a ModportPort<'a>>[src]
Get the underlying ModportPort, or None if the node is not a ModportPort.
pub fn get_modport_simple_port(self) -> Option<&'a ModportSimplePort<'a>>[src]
Get the underlying ModportSimplePort, or None if the node is not a ModportSimplePort.
pub fn get_param_decl(self) -> Option<&'a ParamDecl<'a>>[src]
Get the underlying ParamDecl, or None if the node is not a ParamDecl.
pub fn get_param_type_decl(self) -> Option<&'a ParamTypeDecl<'a>>[src]
Get the underlying ParamTypeDecl, or None if the node is not a ParamTypeDecl.
pub fn get_param_value_decl(self) -> Option<&'a ParamValueDecl<'a>>[src]
Get the underlying ParamValueDecl, or None if the node is not a ParamValueDecl.
pub fn get_cont_assign(self) -> Option<&'a ContAssign<'a>>[src]
Get the underlying ContAssign, or None if the node is not a ContAssign.
pub fn get_generate_for(self) -> Option<&'a GenerateFor<'a>>[src]
Get the underlying GenerateFor, or None if the node is not a GenerateFor.
pub fn get_generate_if(self) -> Option<&'a GenerateIf<'a>>[src]
Get the underlying GenerateIf, or None if the node is not a GenerateIf.
pub fn get_generate_case(self) -> Option<&'a GenerateCase<'a>>[src]
Get the underlying GenerateCase, or None if the node is not a GenerateCase.
pub fn get_generate_block(self) -> Option<&'a GenerateBlock<'a>>[src]
Get the underlying GenerateBlock, or None if the node is not a GenerateBlock.
pub fn get_port_conn(self) -> Option<&'a PortConn<'a>>[src]
Get the underlying PortConn, or None if the node is not a PortConn.
pub fn get_dpi_decl(self) -> Option<&'a DpiDecl<'a>>[src]
Get the underlying DpiDecl, or None if the node is not a DpiDecl.
pub fn get_data_type(self) -> Option<&'a DataType<'a>>[src]
Get the underlying DataType, or None if the node is not a DataType.
pub fn get_implicit_data_type(self) -> Option<&'a ImplicitDataType<'a>>[src]
Get the underlying ImplicitDataType, or None if the node is not a ImplicitDataType.
pub fn get_var_dim(self) -> Option<&'a VarDim<'a>>[src]
Get the underlying VarDim, or None if the node is not a VarDim.
pub fn get_packed_dim(self) -> Option<&'a PackedDim<'a>>[src]
Get the underlying PackedDim, or None if the node is not a PackedDim.
pub fn get_unpacked_dim(self) -> Option<&'a UnpackedDim<'a>>[src]
Get the underlying UnpackedDim, or None if the node is not a UnpackedDim.
pub fn get_path_segment(self) -> Option<&'a PathSegment<'a>>[src]
Get the underlying PathSegment, or None if the node is not a PathSegment.
pub fn is_root(self) -> bool[src]
Check whether this is a Root node.
pub fn is_source_file(self) -> bool[src]
Check whether this is a SourceFile node.
pub fn is_item(self) -> bool[src]
Check whether this is a Item node.
pub fn is_module(self) -> bool[src]
Check whether this is a Module node.
pub fn is_interface(self) -> bool[src]
Check whether this is a Interface node.
pub fn is_package(self) -> bool[src]
Check whether this is a Package node.
pub fn is_type(self) -> bool[src]
Check whether this is a Type node.
pub fn is_type_kind(self) -> bool[src]
Check whether this is a TypeKind node.
pub fn is_enum(self) -> bool[src]
Check whether this is a Enum node.
pub fn is_enum_name(self) -> bool[src]
Check whether this is a EnumName node.
pub fn is_struct(self) -> bool[src]
Check whether this is a Struct node.
pub fn is_struct_member(self) -> bool[src]
Check whether this is a StructMember node.
pub fn is_port(self) -> bool[src]
Check whether this is a Port node.
pub fn is_port_decl(self) -> bool[src]
Check whether this is a PortDecl node.
pub fn is_procedure(self) -> bool[src]
Check whether this is a Procedure node.
pub fn is_stmt(self) -> bool[src]
Check whether this is a Stmt node.
pub fn is_var_decl(self) -> bool[src]
Check whether this is a VarDecl node.
pub fn is_var_decl_name(self) -> bool[src]
Check whether this is a VarDeclName node.
pub fn is_genvar_decl(self) -> bool[src]
Check whether this is a GenvarDecl node.
pub fn is_foreach_index(self) -> bool[src]
Check whether this is a ForeachIndex node.
pub fn is_expr(self) -> bool[src]
Check whether this is a Expr node.
pub fn is_class_decl(self) -> bool[src]
Check whether this is a ClassDecl node.
pub fn is_typedef(self) -> bool[src]
Check whether this is a Typedef node.
pub fn is_subroutine_decl(self) -> bool[src]
Check whether this is a SubroutineDecl node.
pub fn is_subroutine_prototype(self) -> bool[src]
Check whether this is a SubroutinePrototype node.
pub fn is_subroutine_port(self) -> bool[src]
Check whether this is a SubroutinePort node.
pub fn is_net_decl(self) -> bool[src]
Check whether this is a NetDecl node.
pub fn is_pattern_field(self) -> bool[src]
Check whether this is a PatternField node.
pub fn is_import_decl(self) -> bool[src]
Check whether this is a ImportDecl node.
pub fn is_import_item(self) -> bool[src]
Check whether this is a ImportItem node.
pub fn is_inst(self) -> bool[src]
Check whether this is a Inst node.
pub fn is_inst_name(self) -> bool[src]
Check whether this is a InstName node.
pub fn is_modport(self) -> bool[src]
Check whether this is a Modport node.
pub fn is_modport_name(self) -> bool[src]
Check whether this is a ModportName node.
pub fn is_modport_port(self) -> bool[src]
Check whether this is a ModportPort node.
pub fn is_modport_simple_port(self) -> bool[src]
Check whether this is a ModportSimplePort node.
pub fn is_param_decl(self) -> bool[src]
Check whether this is a ParamDecl node.
pub fn is_param_type_decl(self) -> bool[src]
Check whether this is a ParamTypeDecl node.
pub fn is_param_value_decl(self) -> bool[src]
Check whether this is a ParamValueDecl node.
pub fn is_cont_assign(self) -> bool[src]
Check whether this is a ContAssign node.
pub fn is_generate_for(self) -> bool[src]
Check whether this is a GenerateFor node.
pub fn is_generate_if(self) -> bool[src]
Check whether this is a GenerateIf node.
pub fn is_generate_case(self) -> bool[src]
Check whether this is a GenerateCase node.
pub fn is_generate_block(self) -> bool[src]
Check whether this is a GenerateBlock node.
pub fn is_port_conn(self) -> bool[src]
Check whether this is a PortConn node.
pub fn is_dpi_decl(self) -> bool[src]
Check whether this is a DpiDecl node.
pub fn is_data_type(self) -> bool[src]
Check whether this is a DataType node.
pub fn is_implicit_data_type(self) -> bool[src]
Check whether this is a ImplicitDataType node.
pub fn is_var_dim(self) -> bool[src]
Check whether this is a VarDim node.
pub fn is_packed_dim(self) -> bool[src]
Check whether this is a PackedDim node.
pub fn is_unpacked_dim(self) -> bool[src]
Check whether this is a UnpackedDim node.
pub fn is_path_segment(self) -> bool[src]
Check whether this is a PathSegment node.
pub fn unwrap_root(self) -> &'a Root<'a>[src]
Get the underlying Root, or panic if the node is not a Root.
pub fn unwrap_source_file(self) -> &'a SourceFile<'a>[src]
Get the underlying SourceFile, or panic if the node is not a SourceFile.
pub fn unwrap_item(self) -> &'a Item<'a>[src]
Get the underlying Item, or panic if the node is not a Item.
pub fn unwrap_module(self) -> &'a Module<'a>[src]
Get the underlying Module, or panic if the node is not a Module.
pub fn unwrap_interface(self) -> &'a Interface<'a>[src]
Get the underlying Interface, or panic if the node is not a Interface.
pub fn unwrap_package(self) -> &'a Package<'a>[src]
Get the underlying Package, or panic if the node is not a Package.
pub fn unwrap_type(self) -> &'a Type<'a>[src]
Get the underlying Type, or panic if the node is not a Type.
pub fn unwrap_type_kind(self) -> &'a TypeKind<'a>[src]
Get the underlying TypeKind, or panic if the node is not a TypeKind.
pub fn unwrap_enum(self) -> &'a Enum<'a>[src]
Get the underlying Enum, or panic if the node is not a Enum.
pub fn unwrap_enum_name(self) -> &'a EnumName<'a>[src]
Get the underlying EnumName, or panic if the node is not a EnumName.
pub fn unwrap_struct(self) -> &'a Struct<'a>[src]
Get the underlying Struct, or panic if the node is not a Struct.
pub fn unwrap_struct_member(self) -> &'a StructMember<'a>[src]
Get the underlying StructMember, or panic if the node is not a StructMember.
pub fn unwrap_port(self) -> &'a Port<'a>[src]
Get the underlying Port, or panic if the node is not a Port.
pub fn unwrap_port_decl(self) -> &'a PortDecl<'a>[src]
Get the underlying PortDecl, or panic if the node is not a PortDecl.
pub fn unwrap_procedure(self) -> &'a Procedure<'a>[src]
Get the underlying Procedure, or panic if the node is not a Procedure.
pub fn unwrap_stmt(self) -> &'a Stmt<'a>[src]
Get the underlying Stmt, or panic if the node is not a Stmt.
pub fn unwrap_var_decl(self) -> &'a VarDecl<'a>[src]
Get the underlying VarDecl, or panic if the node is not a VarDecl.
pub fn unwrap_var_decl_name(self) -> &'a VarDeclName<'a>[src]
Get the underlying VarDeclName, or panic if the node is not a VarDeclName.
pub fn unwrap_genvar_decl(self) -> &'a GenvarDecl<'a>[src]
Get the underlying GenvarDecl, or panic if the node is not a GenvarDecl.
pub fn unwrap_foreach_index(self) -> &'a ForeachIndex<'a>[src]
Get the underlying ForeachIndex, or panic if the node is not a ForeachIndex.
pub fn unwrap_expr(self) -> &'a Expr<'a>[src]
Get the underlying Expr, or panic if the node is not a Expr.
pub fn unwrap_class_decl(self) -> &'a ClassDecl<'a>[src]
Get the underlying ClassDecl, or panic if the node is not a ClassDecl.
pub fn unwrap_typedef(self) -> &'a Typedef<'a>[src]
Get the underlying Typedef, or panic if the node is not a Typedef.
pub fn unwrap_subroutine_decl(self) -> &'a SubroutineDecl<'a>[src]
Get the underlying SubroutineDecl, or panic if the node is not a SubroutineDecl.
pub fn unwrap_subroutine_prototype(self) -> &'a SubroutinePrototype<'a>[src]
Get the underlying SubroutinePrototype, or panic if the node is not a SubroutinePrototype.
pub fn unwrap_subroutine_port(self) -> &'a SubroutinePort<'a>[src]
Get the underlying SubroutinePort, or panic if the node is not a SubroutinePort.
pub fn unwrap_net_decl(self) -> &'a NetDecl<'a>[src]
Get the underlying NetDecl, or panic if the node is not a NetDecl.
pub fn unwrap_pattern_field(self) -> &'a PatternField<'a>[src]
Get the underlying PatternField, or panic if the node is not a PatternField.
pub fn unwrap_import_decl(self) -> &'a ImportDecl<'a>[src]
Get the underlying ImportDecl, or panic if the node is not a ImportDecl.
pub fn unwrap_import_item(self) -> &'a ImportItem<'a>[src]
Get the underlying ImportItem, or panic if the node is not a ImportItem.
pub fn unwrap_inst(self) -> &'a Inst<'a>[src]
Get the underlying Inst, or panic if the node is not a Inst.
pub fn unwrap_inst_name(self) -> &'a InstName<'a>[src]
Get the underlying InstName, or panic if the node is not a InstName.
pub fn unwrap_modport(self) -> &'a Modport<'a>[src]
Get the underlying Modport, or panic if the node is not a Modport.
pub fn unwrap_modport_name(self) -> &'a ModportName<'a>[src]
Get the underlying ModportName, or panic if the node is not a ModportName.
pub fn unwrap_modport_port(self) -> &'a ModportPort<'a>[src]
Get the underlying ModportPort, or panic if the node is not a ModportPort.
pub fn unwrap_modport_simple_port(self) -> &'a ModportSimplePort<'a>[src]
Get the underlying ModportSimplePort, or panic if the node is not a ModportSimplePort.
pub fn unwrap_param_decl(self) -> &'a ParamDecl<'a>[src]
Get the underlying ParamDecl, or panic if the node is not a ParamDecl.
pub fn unwrap_param_type_decl(self) -> &'a ParamTypeDecl<'a>[src]
Get the underlying ParamTypeDecl, or panic if the node is not a ParamTypeDecl.
pub fn unwrap_param_value_decl(self) -> &'a ParamValueDecl<'a>[src]
Get the underlying ParamValueDecl, or panic if the node is not a ParamValueDecl.
pub fn unwrap_cont_assign(self) -> &'a ContAssign<'a>[src]
Get the underlying ContAssign, or panic if the node is not a ContAssign.
pub fn unwrap_generate_for(self) -> &'a GenerateFor<'a>[src]
Get the underlying GenerateFor, or panic if the node is not a GenerateFor.
pub fn unwrap_generate_if(self) -> &'a GenerateIf<'a>[src]
Get the underlying GenerateIf, or panic if the node is not a GenerateIf.
pub fn unwrap_generate_case(self) -> &'a GenerateCase<'a>[src]
Get the underlying GenerateCase, or panic if the node is not a GenerateCase.
pub fn unwrap_generate_block(self) -> &'a GenerateBlock<'a>[src]
Get the underlying GenerateBlock, or panic if the node is not a GenerateBlock.
pub fn unwrap_port_conn(self) -> &'a PortConn<'a>[src]
Get the underlying PortConn, or panic if the node is not a PortConn.
pub fn unwrap_dpi_decl(self) -> &'a DpiDecl<'a>[src]
Get the underlying DpiDecl, or panic if the node is not a DpiDecl.
pub fn unwrap_data_type(self) -> &'a DataType<'a>[src]
Get the underlying DataType, or panic if the node is not a DataType.
pub fn unwrap_implicit_data_type(self) -> &'a ImplicitDataType<'a>[src]
Get the underlying ImplicitDataType, or panic if the node is not a ImplicitDataType.
pub fn unwrap_var_dim(self) -> &'a VarDim<'a>[src]
Get the underlying VarDim, or panic if the node is not a VarDim.
pub fn unwrap_packed_dim(self) -> &'a PackedDim<'a>[src]
Get the underlying PackedDim, or panic if the node is not a PackedDim.
pub fn unwrap_unpacked_dim(self) -> &'a UnpackedDim<'a>[src]
Get the underlying UnpackedDim, or panic if the node is not a UnpackedDim.
pub fn unwrap_path_segment(self) -> &'a PathSegment<'a>[src]
Get the underlying PathSegment, or panic if the node is not a PathSegment.
pub fn as_any(self) -> &'a dyn AnyNode<'a>[src]
Convert to an AnyNode trait object.