[−][src]Enum moore_svlog_syntax::token::Lit
Abstract literals such as strings.
Variants
Str(Name)UnbasedUnsized(char)One of '0, '1, 'x, and 'z.
A number given as integer and optional fractional part.
A time literal given as integer part, fractional part, and unit.